@@ -46,10 +46,6 @@ impl Logger for WebLogger {
             Log::Warning => console_warn(&format!("[{}] {}", "WARNING", message)),
             Log::Error => console_error(&format!("[{}] {}", "ERROR", message)),
             Log::Debug => console_debug(&format!("[{}] {}", "DEBUG", message)),
-            #[cfg(feature = "profiler")]
-            Log::ProfileStart => console_profile(&message),
-            #[cfg(feature = "profiler")]
-            Log::ProfileEnd => console_profile_end(&message),
         }
     }
 }
